@@ -20,7 +20,7 @@ $WriteMakefileArgs{CONFIGURE} = sub {
 	my $install_these = $ENV{PERL_DATA_TESTIMAGE_INSTALL} // "USC::SIPI=miscellaneous";
 	my @install = split ' ', $install_these;
 	for my $package (@install) {
-		my ($module_part,$args) = split "=", $package;
+		my ($module_part,$args) = split "=", $package, 2;
 		my $module = "Data::TestImage::DB::$module_part";
 		load $module;
 		$module->install_package($args, verbose => 1);
